@@ -209,7 +209,7 @@ if ($data['conditions']) {
 
 		$labelSpan = (new CSpan($label))
 			->addClass('label')
-			->setAttribute('data-type', $condition['type'])
+			->setAttribute('data-conditiontype', $condition['type'])
 			->setAttribute('data-formulaid', $label);
 
 		$condition_table->addRow([
