@@ -36,11 +36,9 @@ class CAuthentication extends CApiService {
 	 * @var array
 	 */
 	private $output_fields = ['authentication_type', 'http_auth_enabled', 'http_login_form', 'http_strip_domains',
-		'http_case_sensitive', 'ldap_configured', 'ldap_case_sensitive', 'ldap_userdirectoryid', 'saml_auth_enabled',
-		'saml_idp_entityid', 'saml_sso_url', 'saml_slo_url', 'saml_username_attribute', 'saml_sp_entityid',
-		'saml_nameid_format', 'saml_sign_messages', 'saml_sign_assertions', 'saml_sign_authn_requests',
-		'saml_sign_logout_requests', 'saml_sign_logout_responses', 'saml_encrypt_nameid', 'saml_encrypt_assertions',
-		'saml_case_sensitive', 'passwd_min_length', 'passwd_check_rules'
+		'http_case_sensitive', 'ldap_auth_enabled', 'ldap_case_sensitive', 'ldap_userdirectoryid', 'saml_auth_enabled',
+		'saml_case_sensitive', 'passwd_min_length', 'passwd_check_rules', 'jit_provision_interval', 'saml_jit_status',
+		'ldap_jit_status', 'disabled_usrgrpid'
 	];
 
 	/**
@@ -120,65 +118,89 @@ class CAuthentication extends CApiService {
 			'http_login_form' =>			['type' => API_INT32, 'in' => ZBX_AUTH_FORM_ZABBIX.','.ZBX_AUTH_FORM_HTTP],
 			'http_strip_domains' =>			['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('config', 'http_strip_domains')],
 			'http_case_sensitive' =>		['type' => API_INT32, 'in' => ZBX_AUTH_CASE_INSENSITIVE.','.ZBX_AUTH_CASE_SENSITIVE],
-			'ldap_configured' =>			['type' => API_INT32, 'in' => ZBX_AUTH_LDAP_DISABLED.','.ZBX_AUTH_LDAP_ENABLED],
+			'ldap_auth_enabled' =>			['type' => API_INT32, 'in' => ZBX_AUTH_LDAP_DISABLED.','.ZBX_AUTH_LDAP_ENABLED],
 			'ldap_case_sensitive' =>		['type' => API_INT32, 'in' => ZBX_AUTH_CASE_INSENSITIVE.','.ZBX_AUTH_CASE_SENSITIVE],
 			'ldap_userdirectoryid' =>		['type' => API_ID],
 			'saml_auth_enabled' =>			['type' => API_INT32, 'in' => ZBX_AUTH_SAML_DISABLED.','.ZBX_AUTH_SAML_ENABLED],
-			'saml_idp_entityid' =>			['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('config', 'saml_idp_entityid')],
-			'saml_sso_url' =>				['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('config', 'saml_sso_url')],
-			'saml_slo_url' =>				['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('config', 'saml_slo_url')],
-			'saml_username_attribute' =>	['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('config', 'saml_username_attribute')],
-			'saml_sp_entityid' =>			['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('config', 'saml_sp_entityid')],
-			'saml_nameid_format' =>			['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('config', 'saml_nameid_format')],
-			'saml_sign_messages' =>			['type' => API_INT32, 'in' => '0,1'],
-			'saml_sign_assertions' =>		['type' => API_INT32, 'in' => '0,1'],
-			'saml_sign_authn_requests' =>	['type' => API_INT32, 'in' => '0,1'],
-			'saml_sign_logout_requests' =>	['type' => API_INT32, 'in' => '0,1'],
-			'saml_sign_logout_responses' =>	['type' => API_INT32, 'in' => '0,1'],
-			'saml_encrypt_nameid' =>		['type' => API_INT32, 'in' => '0,1'],
-			'saml_encrypt_assertions' =>	['type' => API_INT32, 'in' => '0,1'],
 			'saml_case_sensitive' =>		['type' => API_INT32, 'in' => ZBX_AUTH_CASE_INSENSITIVE.','.ZBX_AUTH_CASE_SENSITIVE],
 			'passwd_min_length' =>			['type' => API_INT32, 'in' => '1:70', 'default' => DB::getDefault('config', 'passwd_min_length')],
-			'passwd_check_rules' =>			['type' => API_INT32, 'in' => '0:'.(PASSWD_CHECK_CASE | PASSWD_CHECK_DIGITS | PASSWD_CHECK_SPECIAL | PASSWD_CHECK_SIMPLE), 'default' => DB::getDefault('config', 'passwd_check_rules')]
+			'passwd_check_rules' =>			['type' => API_INT32, 'in' => '0:'.(PASSWD_CHECK_CASE | PASSWD_CHECK_DIGITS | PASSWD_CHECK_SPECIAL | PASSWD_CHECK_SIMPLE), 'default' => DB::getDefault('config', 'passwd_check_rules')],
+			'disabled_usrgrpid' =>			['type' => API_ID],
+			'jit_provision_interval' =>		['type' => API_TIME_UNIT, 'flags' => API_NOT_EMPTY | API_TIME_UNIT_WITH_YEAR, 'in' => implode(':', [SEC_PER_HOUR, 25 * SEC_PER_YEAR])],
+			'saml_jit_status' =>			['type' => API_INT32, 'in' => implode(',', [JIT_PROVISIONING_DISABLED, JIT_PROVISIONING_ENABLED])],
+			'ldap_jit_status' =>			['type' => API_INT32, 'in' => implode(',', [JIT_PROVISIONING_DISABLED, JIT_PROVISIONING_ENABLED])]
 		]];
 
 		if (!CApiInputValidator::validate($api_input_rules, $auth, '/', $error)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		if (array_key_exists('ldap_userdirectoryid', $auth) && $auth['ldap_userdirectoryid'] != 0) {
-			$exists = (bool) API::UserDirectory()->get(['userdirectoryids' => $auth['ldap_userdirectoryid']]);
-
-			if (!$exists) {
-				static::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Invalid parameter "%1$s": %2$s.', '/ldap_userdirectoryid', _('referred object does not exist'))
-				);
-			}
-		}
-
 		$output_fields = $this->output_fields;
 		$output_fields[] = 'configid';
 
 		$db_auth = DB::select('config', ['output' => $output_fields]);
 		$db_auth = reset($db_auth);
+		$auth += $db_auth;
 
-		if (array_key_exists('authentication_type', $auth)) {
-			$auth += $db_auth;
+		// Check if at least one LDAP server exists.
+		if ($auth['ldap_auth_enabled'] == ZBX_AUTH_LDAP_ENABLED) {
+			$ldap_servers_exists = (bool) API::UserDirectory()->get([
+				'countOutput' => true,
+				'filter' => ['idp_type' => IDP_TYPE_LDAP]
+			]);
 
-			if ($auth['authentication_type'] == ZBX_AUTH_LDAP
-					&& $auth['ldap_configured'] == ZBX_AUTH_LDAP_DISABLED) {
+			if (!$ldap_servers_exists) {
+				static::exception(ZBX_API_ERROR_PARAMETERS, _('At least one LDAP server must exist.'));
+			}
+		}
+
+		// Check if default LDAP server exists.
+		if ($auth['ldap_userdirectoryid'] != 0) {
+			$default_ldap_exists = (bool) API::UserDirectory()->get([
+				'countOutput' => true,
+				'userdirectoryids' => [$auth['ldap_userdirectoryid']],
+				'filter' => ['idp_type' => IDP_TYPE_LDAP]
+			]);
+
+			if (!$default_ldap_exists) {
 				static::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Incorrect value for field "%1$s": %2$s.', '/authentication_type', _('LDAP must be enabled'))
+					_s('Invalid parameter "%1$s": %2$s.', '/ldap_userdirectoryid', _('referred object does not exist'))
+				);
+			}
+		}
+
+		// Check if no disabled LDAP is set as default authentication method.
+		if ($auth['authentication_type'] == ZBX_AUTH_LDAP && $auth['ldap_auth_enabled'] == ZBX_AUTH_LDAP_DISABLED) {
+			static::exception(ZBX_API_ERROR_PARAMETERS,
+				_s('Incorrect value for field "%1$s": %2$s.', '/authentication_type', _('LDAP must be enabled'))
+			);
+		}
+
+		// Check if deprovisioning user group exists and is set properly.
+		if ($auth['disabled_usrgrpid']) {
+			$groups = API::UserGroup()->get([
+				'output' => ['users_status'],
+				'usrgrpids' => [$auth['disabled_usrgrpid']]
+			]);
+
+			if (!$groups) {
+				static::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
 				);
 			}
 
-			$have_userdirectories = $auth['ldap_userdirectoryid'] != 0
-				|| API::UserDirectory()->get(['output' => ['userdirectoryid'], 'limit' => 1]);
+			if ($groups[0]['users_status'] != GROUP_STATUS_DISABLED) {
+				static::exception(ZBX_API_ERROR_PARAMETERS, _('Deprovisioned users group cannot be enabled.'));
+			}
+		}
+		else {
+			$ldap_jit_enabled = $auth['ldap_auth_enabled'] == ZBX_AUTH_LDAP_ENABLED
+				&& $auth['ldap_jit_status'] == JIT_PROVISIONING_ENABLED;
+			$saml_jit_enabled = $auth['saml_auth_enabled'] == ZBX_AUTH_SAML_ENABLED
+				&& $auth['saml_jit_status'] == JIT_PROVISIONING_ENABLED;
 
-			if (!$have_userdirectories) {
-				static::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Incorrect value for field "%1$s": %2$s.', '/authentication_type', _('no LDAP servers'))
-				);
+			if ($ldap_jit_enabled || $saml_jit_enabled) {
+				static::exception(ZBX_API_ERROR_PARAMETERS, _('Deprovisioned users group cannot be empty.'));
 			}
 		}
 
